@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.20 2003/11/05 10:22:15 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.22 2003/11/08 23:43:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -133,6 +133,8 @@ typedef struct _RendererContext
   guint link_text_buffer_size;
   guint link_text_length;
 
+  gboolean last_char_is_greater_than;
+
   GHashTable *tag_table;
 
   GtkTextTag *thread_title_tag;
@@ -228,6 +230,12 @@ static GQuark popup_context_id;
 static GQuark popup_parent_context_id;
 
 
+#if ENABLE_REGEXP
+static regex_t head_number_pattern;
+static regex_t informal_link_pattern;
+#endif
+
+
 void
 prepare_thread_ui_initialization(OchushaApplication *application)
 {
@@ -388,7 +396,23 @@ initialize_thread_ui(OchushaApplication *application)
 
 #if !ENABLE_MULTIPLE_POPUPS
   initialize_popup_context(&global_popup_context, application);
-#endif  
+#endif
+
+#if ENABLE_REGEXP
+  if (regcomp(&head_number_pattern,
+	      "^([1-9][0-9]*)", REG_EXTENDED))
+    {
+      fprintf(stderr, "invalid regular expression\n");
+    }
+
+  /* "\076\357\274\236\342\211\253"  ">" UTF-8ɽ */
+  if (regcomp(&informal_link_pattern,
+	      "[\076\357\274\236\342\211\253]+([1-9][0-9]*)",
+	      REG_EXTENDED))
+    {
+      fprintf(stderr, "invalid regular expression\n");
+    }
+#endif
 }
 
 
@@ -799,6 +823,8 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       DEFAULT_BUFFER_SIZE,
       0,
 
+      FALSE,
+
       tag_table,
 
       bbs_thread_view_get_tag_by_name(job_args->view, "thread_title"),
@@ -1279,7 +1305,82 @@ characters_cb(void *user_data, const char *ch, int len)
 
   if (context->link == NULL)
     {
+#if ENABLE_REGEXP
+      if (context->application->analyze_informal_links)
+	{
+	  regmatch_t match[2];
+	  gchar *text = g_strndup(ch, len);
+	  gchar *text_top = text;
+
+	  if (context->last_char_is_greater_than)
+	    {
+	      if (regexec(&head_number_pattern, text, 1,
+			  match, 0) == 0)
+		{
+		  int number;
+		  int match_len = match[1].rm_eo - match[1].rm_so;
+		  if (sscanf(text, "%d", &number) == 1)
+		    {
+		      char *link = ochusha_bbs_thread_get_url_for_response(context->thread, number);
+		      if (link != NULL)
+			{
+			  bbs_thread_view_append_text_as_link(context->view,
+							      text, match_len,
+							      link);
+			  g_free(link);
+			  text_top += match_len;
+			  len -= match_len;
+			}
+		    }
+		}
+	    }
+
+	  while (regexec(&informal_link_pattern, text_top, 1, match, 0) == 0)
+	    {
+	      int no_match_len = match[0].rm_so;
+	      int match_len = match[0].rm_eo - match[0].rm_so;
+	      int number;
+	      char *link;
+
+	      if (no_match_len > 0)
+		bbs_thread_view_append_text(context->view, text_top,
+					    no_match_len);
+	      if (sscanf(text_top + match[1].rm_so, "%d", &number) == 1)
+		link = ochusha_bbs_thread_get_url_for_response(context->thread, number);
+	      else
+		link = NULL;
+
+	      if (link != NULL)
+		{
+		  bbs_thread_view_append_text_as_link(context->view,
+						      text_top + match[0].rm_so,
+						      match_len,
+						      link);
+		  g_free(link);
+		}
+	      else
+		bbs_thread_view_append_text(context->view,
+					    text_top + match[0].rm_so,
+					    match_len);
+
+	      text_top += no_match_len + match_len;
+	      len -= (no_match_len + match_len);
+	    }
+
+	  if (len > 0)
+	    bbs_thread_view_append_text(context->view, text_top, len);
+	  g_free(text);
+
+	  if (ch[len - 1] == '>')
+	    context->last_char_is_greater_than = TRUE;
+	  else
+	    context->last_char_is_greater_than = FALSE;
+	}
+      else
+	bbs_thread_view_append_text(context->view, ch, len);
+#else
       bbs_thread_view_append_text(context->view, ch, len);
+#endif
       return;
     }
 
@@ -1288,8 +1389,10 @@ characters_cb(void *user_data, const char *ch, int len)
 
   while (buffer_size <= (context->link_text_length + len))
     {
+#if DEBUG_GUI_MOST
       fprintf(stderr, "buffer_size=%d, requirement=%d\n",
 	      buffer_size, (context->link_text_length + len));
+#endif
       buffer_size *= 2;
       if (context->link_text_buffer_size == DEFAULT_BUFFER_SIZE)
 	{
@@ -1539,6 +1642,7 @@ render_popup_response(PopupContext *popup_context,
 
   g_signal_connect_after(G_OBJECT(view), "expose_event",
 			 G_CALLBACK(popup_expose_event_cb), popup_context);
+
 #if DEBUG_WIDGET_MOST
   g_signal_connect(G_OBJECT(view), "map_event",
 		   G_CALLBACK(popup_map_event_cb), popup_context);
@@ -1712,6 +1816,12 @@ show_popup_real(PopupContext *popup_context)
       gtk_widget_get_size_request(GTK_WIDGET(popup_context->renderer_context.view),
 				  &w, &h);
 
+#if DEBUG_POPUP
+      fprintf(stderr, "widget=%p, w=%d, h=%d\n",
+	      popup_context->renderer_context.view,
+	      requisition.width, requisition.height);
+#endif
+
       if (requisition.width == 0)
 	{
 	  BBS_THREAD_UI_LOCK
@@ -1801,9 +1911,11 @@ hide_popup_real(PopupContext *popup_context)
 	{
 	  if (popup_context->parent_context != popup_context)
 	    hide_popup(popup_context->parent_context);
+#if DEBUG_POPUP
 	  else
 	    fprintf(stderr, "hide_popup_real(): parent=%p current=%p\n",
 		    popup_context->parent_context, popup_context);
+#endif
 	}
     }
 }
