@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.15 2003/11/05 10:22:15 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.16 2003/11/08 23:31:16 fuyu Exp $
  */
 
 #include "config.h"
@@ -484,6 +484,11 @@ bbs_thread_view_destroy(GtkObject *object)
     {
       regfree(&view->regexp);
       view->regexp_available = FALSE;
+      if (view->regexp_match != NULL)
+	{
+	  G_FREE(view->regexp_match);
+	  view->regexp_match = NULL;
+	}
     }
 #endif
 
@@ -1225,15 +1230,17 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
   if (view->use_regexp)
     {
 #if ENABLE_REGEXP
-      regmatch_t match;
-      int regexec_result = regexec(&view->regexp, text, 1, &match, 0);
+      g_assert(view->regexp_available);
 
-      if (regexec_result == 0)
+      if (regexec(&view->regexp, text, 1, view->regexp_match, 0) == 0)
 	{
 	  gint offset = gtk_text_iter_get_offset(start_iter);
-	  *match_start_offset_p = g_utf8_strlen(text, match.rm_so) + offset;
+	  *match_start_offset_p
+	    = g_utf8_strlen(text, view->regexp_match[0].rm_so) + offset;
 	  *match_end_offset_p
-	    = g_utf8_strlen(text + match.rm_so, match.rm_eo - match.rm_so)
+	    = g_utf8_strlen(text + view->regexp_match[0].rm_so,
+			    (view->regexp_match[0].rm_eo
+			     - view->regexp_match[0].rm_so))
 	    + (*match_start_offset_p);
 	  result = TRUE;
 	}
@@ -1297,18 +1304,19 @@ bbs_thread_view_find_backward_first_match(BBSThreadView *view,
        *       (ޥåʸ¿)ǰξO(n)regexec()¹Ԥ롣
        */
       gboolean found = FALSE;
-      regmatch_t match;
       gchar *tmp_pos = text;
       gchar *last_start_pos = NULL;
       gchar *last_end_pos = NULL;
 
+      g_assert(view->regexp_available);
+
       while (*tmp_pos != '\0'
-	     && regexec(&view->regexp, tmp_pos, 1, &match, 0) == 0)
+	     && regexec(&view->regexp, tmp_pos, 1, view->regexp_match, 0) == 0)
 	{
 	  found = TRUE;
-	  last_start_pos = match.rm_so + tmp_pos;
-	  last_end_pos = match.rm_eo + tmp_pos;
-	  tmp_pos += match.rm_eo;
+	  last_start_pos = view->regexp_match[0].rm_so + tmp_pos;
+	  last_end_pos = view->regexp_match[0].rm_eo + tmp_pos;
+	  tmp_pos += view->regexp_match[0].rm_eo;
 	}
 
       if (found)
@@ -1502,7 +1510,15 @@ bbs_thread_view_find(BBSThreadView *view, const gchar *key,
     {
       int regcomp_result;
       if (view->regexp_available)
-	regfree(&view->regexp);
+	{
+	  regfree(&view->regexp);
+	  if (view->regexp_match != NULL)
+	    {
+	      G_FREE(view->regexp_match);
+	      view->regexp_match = NULL;
+	    }
+	}
+
       if (match_case)
 	regcomp_result = regcomp(&view->regexp, key,
 				 REG_EXTENDED | REG_NEWLINE);
@@ -1516,7 +1532,10 @@ bbs_thread_view_find(BBSThreadView *view, const gchar *key,
 	  result = FALSE;
 	}
       else
-	view->regexp_available = TRUE;
+	{
+	  view->regexp_available = TRUE;
+	  view->regexp_match = G_NEW0(regmatch_t, 1 + view->regexp.re_nsub);
+	}
     }
   else
     {
@@ -1601,6 +1620,11 @@ bbs_thread_view_invalidate_search_result(BBSThreadView *view)
     {
       regfree(&view->regexp);
       view->regexp_available = FALSE;
+      if (view->regexp_match != NULL)
+	{
+	  G_FREE(view->regexp_match);
+	  view->regexp_match = NULL;
+	}
     }
 #endif
 
