@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.19 2003/11/05 11:00:17 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.21 2003/11/08 23:43:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -171,10 +171,14 @@ prepare_boardlist_ui_initialization(OchushaApplication *application)
 
   category_gui_info_id
     = g_quark_from_static_string("BoardlistUI::CategoryInfo");
+}
 
-#if HAVE_ONIGURUMA
-  reg_set_encoding(REG_ENCODING_UTF8);
-#endif
+
+static void
+open_view_cb(GtkWidget *selector, gpointer item, gboolean in_tab,
+	     PanedNotebook *paned_notebook)
+{
+  paned_notebook_open_item_view(paned_notebook, item, in_tab);
 }
 
 
@@ -182,6 +186,7 @@ void
 initialize_boardlist(OchushaApplication *application)
 {
   GtkToolbar *toolbar;
+  GtkWidget *scrolled_window;
   GtkWidget *filter_button;
 
   board_list = NULL;
@@ -208,9 +213,19 @@ initialize_boardlist(OchushaApplication *application)
 #endif
   gtk_widget_show(application->boardlist_view);
 
+  scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
+				      GTK_SHADOW_ETCHED_IN);
+  gtk_container_add(GTK_CONTAINER(scrolled_window),
+		    application->boardlist_view);
+
   application->contents_window
     = paned_notebook_new_with_selector(application->boardlist_pane_style,
-				       application->boardlist_view);
+				       scrolled_window);
+  g_signal_connect(G_OBJECT(application->boardlist_view), "open_view",
+		   G_CALLBACK(open_view_cb), application->contents_window);
   gtk_paned_set_position(GTK_PANED(application->contents_window),
 			 application->boardlist_width);
   paned_notebook_set_always_show_contents_pane(PANED_NOTEBOOK(application->contents_window),
@@ -546,8 +561,13 @@ do_search_on_current_threadlist(OchushaApplication *application,
   widget = paned_notebook_get_selector(PANED_NOTEBOOK(widget));
   if (widget == NULL)
     return FALSE;
+
+  g_return_val_if_fail(GTK_IS_SCROLLED_WINDOW(widget), FALSE);
+  widget = gtk_bin_get_child(GTK_BIN(widget));
+
   g_return_val_if_fail(IS_THREADLIST_VIEW(widget), FALSE);
   view = THREADLIST_VIEW(widget);
+
   search_query_data.last_view = view;
   threadlist_view_set_being_searched(view, TRUE);
 
@@ -766,6 +786,7 @@ void
 update_threadlist_entry(OchushaApplication *application, OchushaBBSThread *thread)
 {
   PanedNotebook *board_view;
+  GtkWidget *scrolled_window;
   ThreadlistView *threadlist_view;
   PanedNotebook *boardlist = (PanedNotebook *)application->contents_window;
 
@@ -778,15 +799,18 @@ update_threadlist_entry(OchushaApplication *application, OchushaBBSThread *threa
   if (board_view == NULL)
     goto finish_update;	/* ĤɽƤʤ⤢ */
 
-  threadlist_view = (ThreadlistView *)paned_notebook_get_selector(board_view);
+  scrolled_window = paned_notebook_get_selector(board_view);
 
-  if (threadlist_view == NULL)
+  if (scrolled_window == NULL)
     {
       goto finish_update;	/* ե륿ߤǥɽƤʤ
 				 * ⤢롣
 				 */
     }
 
+  threadlist_view
+    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+
   update_threadlist_entry_style(application, threadlist_view, thread);
 
  finish_update:
@@ -966,18 +990,22 @@ page_switched_cb(PanedNotebook *paned_notebook,
 
   if (previous_page != NULL)
     {
-      gpointer threadlist_view;
+      GtkWidget *scrolled_window;
+
       application->threadlist_height
 	= gtk_paned_get_position(GTK_PANED(previous_page));
-      threadlist_view
+      scrolled_window
 	= paned_notebook_get_selector(PANED_NOTEBOOK(previous_page));
 
-      if (IS_THREADLIST_VIEW(threadlist_view)
-	  && search_query_data.last_view == threadlist_view)
+      if (scrolled_window != NULL)
 	{
-	  threadlist_view_set_being_searched(THREADLIST_VIEW(threadlist_view),
-					     FALSE);
-	  search_query_data.last_view = NULL;
+	  ThreadlistView *threadlist_view
+	    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+	  if (search_query_data.last_view == threadlist_view)
+	    {
+	      threadlist_view_set_being_searched(threadlist_view, FALSE);
+	      search_query_data.last_view = NULL;
+	    }
 	}
     }
 
