@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.h,v 1.5 2003/06/21 14:52:21 fuyu Exp $
+ * $Id: boardlist_view.h,v 1.6 2003/11/07 14:27:06 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -51,9 +51,8 @@ typedef struct _BoardlistViewClass BoardlistViewClass;
 
 struct _BoardlistView
 {
-  GtkScrolledWindow container;
+  GtkTreeView view;
 
-  GtkTreeView *view;
   GtkTreeModel *model;
 
   GtkTreeSelection *selection;
@@ -66,7 +65,7 @@ struct _BoardlistView
 
 struct _BoardlistViewClass
 {
-  GtkScrolledWindowClass parent_class;
+  GtkTreeViewClass parent_class;
 
   void (*open_view)(BoardlistView *boardlist_view, OchushaBulletinBoard *board,
 		    gboolean in_tab);
@@ -89,8 +88,6 @@ struct _BoardlistViewClass
 
   gboolean (*advance_view)(BoardlistView *boardlist_view);
   gboolean (*back_view)(BoardlistView *boardlist_view);
-  gboolean (*move_cursor)(BoardlistView *boardlist_view, GtkMovementStep step,
-			  gint count);
 
   void (*do_on_selection)(BoardlistView *boardlist_view,
 			  int what_to_do);
