@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.39 2003/11/05 11:00:17 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.42 2003/11/08 20:02:47 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,6 +64,8 @@ static void open_thread_view(WorkerThread *employee, gpointer job_args);
 static void show_threadlist(WorkerThread *employee, gpointer args);
 static void advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			    PanedNotebook *paned_notebook);
+static void back_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
+			 PanedNotebook *paned_notebook);
 static void toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
 static void toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
@@ -459,6 +461,10 @@ customize_threadlist_view_contents(OchushaApplication *application,
 	  threadlist_view_append_rank_difference(view);
 	  break;
 
+	case 'L':
+	  threadlist_view_append_last_modified(view);
+	  break;
+
 	default:
 	  fprintf(stderr, "'%c' doesn't match any column\n", *column);
 	  break;
@@ -468,6 +474,14 @@ customize_threadlist_view_contents(OchushaApplication *application,
 }
 
 
+static void
+open_view_cb(GtkWidget *selector, gpointer item, gboolean in_tab,
+	     PanedNotebook *paned_notebook)
+{
+  paned_notebook_open_item_view(paned_notebook, item, in_tab);
+}
+
+
 GtkWidget *
 open_bulletin_board(OchushaApplication *application,
 		    OchushaBulletinBoard *board, IconLabel *tab_label)
@@ -486,6 +500,7 @@ open_bulletin_board(OchushaApplication *application,
     {
       WorkerJob *job;
       ThreadlistJobArgs *job_args;
+      GtkWidget *scrolled_window;
       GtkWidget *view;
       GtkToolbar *toolbar;
 
@@ -498,6 +513,12 @@ open_bulletin_board(OchushaApplication *application,
 	  return NULL;
 	}
 
+      scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
+				     GTK_POLICY_AUTOMATIC,
+				     GTK_POLICY_AUTOMATIC);
+      gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_window),
+					  GTK_SHADOW_ETCHED_IN);
       view = threadlist_view_new();
       customize_threadlist_view_contents(application, THREADLIST_VIEW(view));
 
@@ -505,9 +526,14 @@ open_bulletin_board(OchushaApplication *application,
       job_args = G_NEW0(ThreadlistJobArgs, 1);
 
       gtk_widget_show(view);
+      gtk_container_add(GTK_CONTAINER(scrolled_window), view);
+      gtk_widget_show(scrolled_window);
+
       paned_notebook
 	= paned_notebook_new_with_selector(application->threadlist_pane_style,
-					   view);
+					   scrolled_window);
+      g_signal_connect(G_OBJECT(view), "open_view",
+		       G_CALLBACK(open_view_cb), paned_notebook);
       gtk_paned_set_position(GTK_PANED(paned_notebook),
 			     application->threadlist_height);
       paned_notebook_set_tab_shrinkable(PANED_NOTEBOOK(paned_notebook),
@@ -563,6 +589,8 @@ open_bulletin_board(OchushaApplication *application,
 
       g_signal_connect(G_OBJECT(view), "advance_view",
 		       G_CALLBACK(advance_view_cb), paned_notebook);
+      g_signal_connect(G_OBJECT(view), "back_view",
+		       G_CALLBACK(back_view_cb), paned_notebook);
       g_signal_connect(G_OBJECT(view), "toggle_mark",
 		       G_CALLBACK(toggle_mark_cb), application);
       g_signal_connect(G_OBJECT(view), "toggle_hide",
@@ -623,6 +651,7 @@ open_bulletin_board(OchushaApplication *application,
       commit_job(job);
     }
   THREAD_LIST_UNLOCK;
+
   return paned_notebook;
 }
 
@@ -723,6 +752,7 @@ refresh_threadlist_view(OchushaApplication *application,
 			OchushaBulletinBoard *board)
 {
   PanedNotebook *contents_window;
+  GtkWidget *scrolled_window;
   ThreadlistView *threadlist_view;
   PanedNotebook *board_view;
   WorkerJob *job;
@@ -738,8 +768,11 @@ refresh_threadlist_view(OchushaApplication *application,
   tab_label = (IconLabel *)paned_notebook_get_tab_label(contents_window,
 							board);
 
-  threadlist_view = (ThreadlistView *)paned_notebook_get_selector(board_view);
-  g_return_if_fail(threadlist_view != NULL);
+  scrolled_window = paned_notebook_get_selector(board_view);
+  g_return_if_fail(scrolled_window != NULL);
+
+  threadlist_view
+    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
 
   THREAD_LIST_LOCK
     {
@@ -799,6 +832,7 @@ redraw_threadlist_view(OchushaApplication *application,
 		       OchushaBulletinBoard *board)
 {
   PanedNotebook *contents_window;
+  GtkWidget *scrolled_window;
   ThreadlistView *threadlist_view;
   PanedNotebook *board_view;
   WorkerJob *job;
@@ -816,8 +850,11 @@ redraw_threadlist_view(OchushaApplication *application,
   tab_label = (IconLabel *)paned_notebook_get_tab_label(contents_window,
 							board);
 
-  threadlist_view = (ThreadlistView *)paned_notebook_get_selector(board_view);
-  g_return_if_fail(threadlist_view != NULL);
+  scrolled_window = paned_notebook_get_selector(board_view);
+  g_return_if_fail(scrolled_window != NULL);
+
+  threadlist_view
+    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
 
   THREAD_LIST_LOCK
     {
@@ -1115,12 +1152,35 @@ advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 {
   if (paned_notebook_get_current_item(paned_notebook) != thread)
     paned_notebook_open_item_view(paned_notebook, thread, FALSE);
-#if 0
   else
     {
       /* ڡ򥹥뤵 */
+      GtkWidget *scrolled_window
+	= paned_notebook_get_current_item_view(paned_notebook);
+      BBSThreadView *thread_view
+	= BBS_THREAD_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+      g_signal_emit_by_name(G_OBJECT(thread_view), "move_cursor",
+			    GTK_MOVEMENT_PAGES, 1, FALSE);
+    }
+}
+
+
+static void
+back_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
+	     PanedNotebook *paned_notebook)
+{
+  if (paned_notebook_get_current_item(paned_notebook) != thread)
+    paned_notebook_open_item_view(paned_notebook, thread, FALSE);
+  else
+    {
+      /* ڡ򥹥뤵 */
+      GtkWidget *scrolled_window
+	= paned_notebook_get_current_item_view(paned_notebook);
+      BBSThreadView *thread_view
+	= BBS_THREAD_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+      g_signal_emit_by_name(G_OBJECT(thread_view), "move_cursor",
+			    GTK_MOVEMENT_PAGES, -1, FALSE);
     }
-#endif
 }
 
 
@@ -1290,6 +1350,11 @@ item_view_required_cb(PanedNotebook *paned_notebook,
     {
       gtk_widget_show(thread_view);
       *item_view = gtk_scrolled_window_new(NULL, NULL);
+      gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(*item_view),
+				     GTK_POLICY_AUTOMATIC,
+				     GTK_POLICY_AUTOMATIC);
+      gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(*item_view),
+					  GTK_SHADOW_ETCHED_IN);
       gtk_container_add(GTK_CONTAINER(*item_view), thread_view);
       gtk_widget_show(*item_view);
     }
@@ -1406,8 +1471,12 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
   ochusha_async_buffer_resume_all();
 #endif
 
-  if (application->last_search_target_widget == item_view)
-    application->last_search_target_widget = NULL;
+  if (item_view != NULL)
+    {
+      GtkWidget *thread_view = gtk_bin_get_child(GTK_BIN(item_view));
+      if (application->last_search_target_widget == thread_view)
+	application->last_search_target_widget = NULL;
+    }
 }
 
 
@@ -1436,6 +1505,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
 		 GtkWidget *previous_page, GtkWidget *new_page,
 		 OchushaApplication *application)
 {
+  GtkWidget *scrolled_window;
   ThreadlistView *threadlist_view;
   OchushaBBSThread *thread;
   BBSThreadGUIInfo *info;
@@ -1476,12 +1546,14 @@ page_switched_cb(PanedNotebook *paned_notebook,
   }
 #endif
 
-  threadlist_view
-    = (ThreadlistView *)paned_notebook_get_selector(paned_notebook);
+  scrolled_window = paned_notebook_get_selector(paned_notebook);
   thread = paned_notebook_get_item(paned_notebook, new_page);
-  if (threadlist_view == NULL || thread == NULL)
+  if (scrolled_window == NULL || thread == NULL)
     return;
 
+  threadlist_view
+    = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+
   info = ensure_bbs_thread_info(thread);
   if (info->next_mark != NULL)
     {
@@ -1540,11 +1612,14 @@ finalize_bulletin_board_view(OchushaBulletinBoard *board, GtkWidget *widget)
 			      NULL);
 #if DEBUG_WIDGET
   {
-    ThreadlistView *threadlist_view
-      = (ThreadlistView *)paned_notebook_get_selector(board_view);
-    if (threadlist_view != NULL)
-      fprintf(stderr, "finalize: threadlist_view->ref_count=%d\n",
-	      G_OBJECT(threadlist_view)->ref_count);
+    GtkWidget *scrolled_window = paned_notebook_get_selector(board_view);
+    if (scrolled_window != NULL)
+      {
+	ThreadlistView *threadlist_view
+	  = THREADLIST_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+	fprintf(stderr, "finalize: threadlist_view->ref_count=%d\n",
+		G_OBJECT(threadlist_view)->ref_count);
+      }
   }
 #endif
 }
@@ -1786,7 +1861,8 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
 
   if (application->last_search_target_widget != widget)
     {
-      if (IS_BBS_THREAD_VIEW(application->last_search_target_widget))
+      if (application->last_search_target_widget != NULL
+	  && IS_BBS_THREAD_VIEW(application->last_search_target_widget))
 	bbs_thread_view_invalidate_search_result(BBS_THREAD_VIEW(application->last_search_target_widget));
       application->last_search_target_widget = widget;
     }
