@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.5 2003/06/21 16:37:42 fuyu Exp $
+ * $Id: main.c,v 1.7 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -38,10 +38,12 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <libxml/parser.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 
+
 #define INITIAL_NUM_THREADS	2
 #define MAXIMUM_NUM_THREADS	32
 
@@ -69,6 +71,8 @@ main(int argc, char *argv[])
 
   bind_textdomain_codeset(PACKAGE_NAME, "UTF-8");
 
+  xmlInitParser();
+
   initialize_default_entity_dictionary();
   initialize_common_converters();
   initialize_worker(INITIAL_NUM_THREADS, MAXIMUM_NUM_THREADS);
@@ -94,6 +98,7 @@ main(int argc, char *argv[])
   gdk_threads_leave();
 
   terminate_workers();
+  xmlCleanupParser();
 
 #if TRACE_MEMORY_USAGE
   g_object_unref(G_OBJECT(application->table));
@@ -118,6 +123,18 @@ main(int argc, char *argv[])
   G_FREE(application->config.proxy_password);
   application->config.proxy_password = NULL;
 
+  if (application->last_name != NULL)
+    {
+      G_FREE(application->last_name);
+      application->last_name = NULL;
+    }
+
+  if (application->last_mail != NULL)
+    {
+      G_FREE(application->last_mail);
+      application->last_mail = NULL;
+    }
+
   G_FREE(application);
 
   dump_pointers();
