@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.21 2003/11/05 11:00:18 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.24 2003/11/08 23:43:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -55,6 +55,9 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <time.h>
+
+
 #include "blue0.xpm"
 #include "blue1.xpm"
 #include "blue2.xpm"
@@ -64,7 +67,15 @@
 #include "red.xpm"
 
 #include "ochusha48.xpm"
+
+#if USE_BANNER_XPM
 #include "ochusha-banner.xpm"
+#include "ochusha-banner1.xpm"
+#else
+#include "ochusha-banner.h"
+#include "ochusha-banner1.h"
+#endif
+
 
 static void setup_tab_label_icons(void);
 static void delete_event_cb(GtkWidget *widget, GdkEventAny *event,
@@ -140,6 +151,7 @@ static pthread_mutex_t main_ui_lock;
 
 static GtkWidget *about_dialog = NULL;
 static GdkPixbuf *banner_pixbuf = NULL;
+static GdkPixbuf *banner1_pixbuf = NULL;
 static GtkWidget *open_url_dialog = NULL;
 static GtkWidget *open_url_combo = NULL;
 static GtkWidget *open_url_in_tab_button = NULL;
@@ -277,13 +289,20 @@ ochusha_init_application(OchushaApplication *application)
 
   setup_tab_label_icons();
 
+#if USE_BANNER_XPM
   banner_pixbuf
     = gdk_pixbuf_new_from_xpm_data((const char **)ochusha_banner_xpm);
+  banner1_pixbuf
+    = gdk_pixbuf_new_from_xpm_data((const char **)ochusha_banner1_xpm);
+#else
+  banner_pixbuf
+    = gdk_pixbuf_new_from_inline(-1, ochusha_banner_inline, FALSE, NULL);
+  banner1_pixbuf
+    = gdk_pixbuf_new_from_inline(-1, ochusha_banner1_inline, FALSE, NULL);
+#endif
 
   configure_application(application);
 
-  ugly_gtk_tree_view_unbind_keys();
-
   application->top_level = GTK_WINDOW(gtk_window_new(GTK_WINDOW_TOPLEVEL));
   g_signal_connect(G_OBJECT(application->top_level), "delete_event",
 		   G_CALLBACK(delete_event_cb), application);
@@ -396,6 +415,11 @@ ochusha_init_application(OchushaApplication *application)
 		   G_CALLBACK(gtk_widget_destroyed), &application->url_box);
 #endif
 #endif	/* ENABLE_MAIN_TOOLBAR */
+
+#if ENABLE_REGEXP && HAVE_ONIGURUMA
+  reg_set_encoding(REG_ENCODING_UTF8);
+#endif
+
   /* ν */
   initialize_open_url_dialog(application);
 
@@ -796,6 +820,8 @@ write_optional_prefs(FILE *file, gpointer user_data)
 				  enable_smart_popup_placement);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application,
 			      maximum_number_of_popup_responses);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  analyze_informal_links);
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, web_browser_template);
 
@@ -876,9 +902,12 @@ configure_application(OchushaApplication *application)
 	= OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE;
       application->popup_response_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
       application->popup_close_delay = OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY;
-      application->enable_smart_popup_placement = FALSE;
+      application->enable_smart_popup_placement
+	= OCHUSHA_DEFAULT_ENABLE_SMART_POPUP_PLACEMENT;
       application->maximum_number_of_popup_responses
 	= OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES;
+      application->analyze_informal_links
+	= OCHUSHA_DEFAULT_ANALYZE_INFORMAL_LINKS;
 
       application->show_threadlist_entry_when_thread_selected
 	= OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
@@ -1068,7 +1097,8 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
       = ochusha_utils_get_attribute_boolean(pref_attrs,
 					    "enable_smart_popup_placement");
   else
-    application->enable_smart_popup_placement = TRUE;
+    application->enable_smart_popup_placement
+      = OCHUSHA_DEFAULT_ENABLE_SMART_POPUP_PLACEMENT;
 
   if (g_hash_table_lookup(pref_attrs, "maximum_number_of_popup_responses")
       != NULL)
@@ -1079,6 +1109,14 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     application->maximum_number_of_popup_responses
       = OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES;
 
+  if (g_hash_table_lookup(pref_attrs, "analyze_informal_links") != NULL)
+    application->analyze_informal_links
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "analyze_informal_links");
+  else
+    application->analyze_informal_links
+      = OCHUSHA_DEFAULT_ANALYZE_INFORMAL_LINKS;
+
   application->web_browser_template
     = ochusha_utils_get_attribute_string(pref_attrs, "web_browser_template");
 
@@ -1244,6 +1282,8 @@ open_about_dialog(OchushaApplication *application)
 	{
 	  gchar text_buffer[1024];
 	  GtkWidget *label;
+	  GdkPixbuf *banner = NULL;
+
 	  about_dialog = gtk_dialog_new_with_buttons(_("About Ochusha"),
 					application->top_level,
 					GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -1261,8 +1301,22 @@ open_about_dialog(OchushaApplication *application)
 	  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox),
 			    label);
 
+#ifdef HAVE_LOCALTIME_R
+	  {
+	    struct tm tm;
+	    time_t utc = time(NULL);
+	    localtime_r(&utc, &tm);
+
+	    if (tm.tm_year == 104 && tm.tm_yday < 7)
+	      banner = banner1_pixbuf;
+	    else
+	      banner = banner_pixbuf;
+	  }
+#else
+	  banner = banner_pixbuf;
+#endif
 	  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox),
-			    gtk_image_new_from_pixbuf(banner_pixbuf));
+			    gtk_image_new_from_pixbuf(banner));
 
 	  label = gtk_label_new("Copyright(c) 2003 The Ochusha Project");
 	  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox),
