@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.16 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.18 2003/11/08 23:43:25 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -96,7 +96,7 @@
 #define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS			TRUE
 #define OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED	FALSE
 
-#define OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS		"RMTNnUD"
+#define OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS		"RMTNnUDL"
 
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE				FALSE
 #define OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE				TRUE
@@ -105,6 +105,9 @@
 #define OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY				100
 #define OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES		5
 
+#define OCHUSHA_DEFAULT_ENABLE_SMART_POPUP_PLACEMENT			TRUE
+#define OCHUSHA_DEFAULT_ANALYZE_INFORMAL_LINKS				TRUE
+
 #define OCHUSHA_DEFAULT_HIDE_HIDDEN_BOARDLIST_ITEMS			FALSE
 #define OCHUSHA_DEFAULT_HIDE_HIDDEN_THREADS				FALSE
 
@@ -214,6 +217,7 @@ struct _OchushaApplication
   guint popup_close_delay;
   gboolean enable_smart_popup_placement;
   gint maximum_number_of_popup_responses;
+  gboolean analyze_informal_links;
 
 
   /* ֥֥饦Υޥɥ饤ƥץ졼 */
