@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.8 2003/11/05 07:54:50 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.10 2003/11/07 15:52:40 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -69,9 +69,8 @@ typedef enum {
 
 struct _ThreadlistView
 {
-  GtkScrolledWindow container;
+  GtkTreeView view;
 
-  GtkTreeView *view;
   GtkTreeModel *model;
 
   GtkTreeViewColumn *rank_column;
@@ -81,6 +80,7 @@ struct _ThreadlistView
   GtkTreeViewColumn *n_read_column;
   GtkTreeViewColumn *n_unread_column;
   GtkTreeViewColumn *rank_diff_column;
+  GtkTreeViewColumn *last_modified_column;
 
   GtkTreeSelection *selection;
 
@@ -103,7 +103,7 @@ struct _ThreadlistView
 
 struct _ThreadlistViewClass
 {
-  GtkScrolledWindowClass parent_class;
+  GtkTreeViewClass parent_class;
 
   void (*open_view)(ThreadlistView *threadlist_view, OchushaBBSThread *thread,
 		    gboolean in_tab);
@@ -126,8 +126,6 @@ struct _ThreadlistViewClass
   gboolean (*back_view)(ThreadlistView *threadlist_view,
 			OchushaBBSThread *thread);
 
-  gboolean (*move_cursor)(ThreadlistView *threadlist_view,
-			  GtkMovementStep step, gint count);
   gboolean (*interactive_search)(ThreadlistView *threadlist_view,
 				 ThreadlistSearchAction search_action);
 
@@ -202,6 +200,7 @@ void threadlist_view_append_number_of_responses(ThreadlistView *view);
 void threadlist_view_append_number_of_responses_read(ThreadlistView *view);
 void threadlist_view_append_number_of_responses_unread(ThreadlistView *view);
 void threadlist_view_append_rank_difference(ThreadlistView *view);
+void threadlist_view_append_last_modified(ThreadlistView *view);
 
 void threadlist_view_initialize_default_view(ThreadlistView *view);
 
