@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: gziputils.h,v 1.1.1.1 2003/05/10 16:34:27 fuyu Exp $
+ * $Id: gziputils.h,v 1.3 2003/06/10 21:14:58 fuyu Exp $
  */
 
 #ifndef _GZIPUTILS_H_
@@ -52,11 +52,14 @@ typedef enum
 GzipBuffer *gzip_buffer_new(OchushaAsyncBuffer *async_buffer);
 void gzip_buffer_free(GzipBuffer *buffer);
 
+void gzip_buffer_skip_gzip_header(GzipBuffer *buffer);
 GzipBufferStatus gzip_buffer_append_data(GzipBuffer *buffer, const char *data,
 					 unsigned int length);
 
+#if 0	/* ⤦ȤäƤʤ */
 gboolean inflate_gzip_buffer(const char *input, unsigned int input_length,
 			     char **output, unsigned int *output_length);
+#endif
 
 #ifdef __cplusplus
 } // extern "C"
