@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.9 2003/07/13 14:53:51 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.11 2003/11/08 23:44:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -168,7 +168,9 @@ ochusha_bbs_thread_class_init(OchushaBBSThreadClass *klass)
 
   klass->get_responses_source = NULL;
   klass->parse_responses = NULL;
+  klass->get_last_modified_utc = NULL;
   klass->get_url = NULL;
+  klass->get_url_for_response = NULL;
   klass->get_url_to_post = NULL;
   klass->check_url = NULL;
   klass->remove_cache = NULL;
@@ -424,6 +426,22 @@ ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 }
 
 
+time_t
+ochusha_bbs_thread_get_last_modified_utc(OchushaBBSThread *thread)
+{
+  OchushaBBSThreadClass *klass;
+
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), 0);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+
+  if (klass->get_last_modified_utc == NULL)
+    return 0;
+
+  return (*klass->get_last_modified_utc)(thread);
+}
+
+
 gboolean
 ochusha_bbs_thread_is_preview_supported(OchushaBBSThread *thread)
 {
@@ -488,6 +506,34 @@ ochusha_bbs_thread_post_response(OchushaBBSThread *thread,
 }
 
 
+const char *
+ochusha_bbs_thread_get_url(OchushaBBSThread *thread)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  g_return_val_if_fail(klass->get_url != NULL, NULL);
+
+  return (*klass->get_url)(thread);
+}
+
+
+char *
+ochusha_bbs_thread_get_url_for_response(OchushaBBSThread *thread, int number)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+
+  if (klass->get_url_for_response != NULL)
+    return (*klass->get_url_for_response)(thread, number);
+  else
+    return NULL;
+}
+
+
 const char *
 ochusha_bbs_thread_get_url_to_post_response(OchushaBBSThread *thread)
 {
@@ -503,19 +549,6 @@ ochusha_bbs_thread_get_url_to_post_response(OchushaBBSThread *thread)
 }
 
 
-const char *
-ochusha_bbs_thread_get_url(OchushaBBSThread *thread)
-{
-  OchushaBBSThreadClass *klass;
-  g_return_val_if_fail(OCHUSHA_IS_BBS_THREAD(thread), NULL);
-
-  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
-  g_return_val_if_fail(klass->get_url != NULL, NULL);
-
-  return (*klass->get_url)(thread);
-}
-
-
 gboolean
 ochusha_bbs_thread_check_url(OchushaBBSThread *thread, const char *url,
 			     unsigned int *from_p, unsigned int *to_p)
