@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.8 2003/11/02 21:30:43 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.10 2003/11/08 23:44:33 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -37,6 +37,8 @@
 #include <glib-object.h>
 #include <glib.h>
 
+#include <time.h>
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -78,7 +80,6 @@ struct _OchushaBBSThread
   /* ɥ쥹(ɤ߹쥹) */
   int number_of_responses_read;
 
-
   /* Ĥ˴ؤäȤ(OchushaBBSThreadStateORȤä) */
   int flags;	/* XXX: ΤȤ̤ */
 };
@@ -112,7 +113,9 @@ struct _OchushaBBSThreadClass
 			      BrokenResponseCallback *broken_response_callback,
 			      EndThreadCallback *end_thread_callback,
 			      gpointer callback_data);
+  time_t (*get_last_modified_utc)(OchushaBBSThread *thread);
   const char *(*get_url)(OchushaBBSThread *thread);
+  char *(*get_url_for_response)(OchushaBBSThread *thread, int number);
   const char *(*get_url_to_post)(OchushaBBSThread *thread);
   gboolean (*check_url)(OchushaBBSThread *thread, const char *url,
 			unsigned int *from_p, unsigned int *to_p);
@@ -163,7 +166,10 @@ const gchar *ochusha_bbs_thread_get_title(OchushaBBSThread *thread);
 int ochusha_bbs_thread_get_number_of_responses_on_server(OchushaBBSThread *thread);
 int ochusha_bbs_thread_get_number_of_responses_read(OchushaBBSThread *thread);
 
+time_t ochusha_bbs_thread_get_last_modified_utc(OchushaBBSThread *thread);
+
 const char *ochusha_bbs_thread_get_url(OchushaBBSThread *thread);
+char *ochusha_bbs_thread_get_url_for_response(OchushaBBSThread *thread, int number);
 
 gboolean ochusha_bbs_thread_is_preview_supported(OchushaBBSThread *thread);
 gboolean ochusha_bbs_thread_is_post_supported(OchushaBBSThread *thread);
