@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.4 2003/06/20 18:10:06 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.5 2003/07/13 14:53:51 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -120,6 +120,7 @@ struct _OchushaBulletinBoardClass
 				 gpointer callback_data);
 
   const char *(*get_response_character_encoding)(OchushaBulletinBoard *board);
+  iconv_helper *(*get_response_iconv_helper)(OchushaBulletinBoard *board);
 };
 
 
@@ -160,7 +161,8 @@ gboolean ochusha_bulletin_board_refresh_threadlist(OchushaBulletinBoard *board,
 						   gpointer callback_data);
 const char *ochusha_bulletin_board_get_response_character_encoding(
 						OchushaBulletinBoard *board);
-
+iconv_helper *ochusha_bulletin_board_get_response_iconv_helper(
+						OchushaBulletinBoard *board);
 
 gboolean ochusha_bulletin_board_read_threadlist_xml(
 					OchushaBulletinBoard *board,
