@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.12 2003/11/04 07:56:41 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.14 2003/11/08 23:44:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -40,6 +40,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <unistd.h>
 
 
@@ -83,6 +84,8 @@ static gboolean ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 						   EndThreadCallback *end_cb,
 						   gpointer callback_data);
 
+static time_t ochusha_thread_2ch_get_last_modified_utc(OchushaBBSThread *thread);
+
 static gboolean ochusha_thread_2ch_preview_response(OchushaBBSThread *thread,
 					const OchushaBBSResponse *response,
 					StartThreadCallback *start_cb,
@@ -94,6 +97,8 @@ static gboolean ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 					OchushaConfig *config,
 					const OchushaBBSResponse *response);
 
+static char *ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread,
+						     int number);
 static const char *ochusha_thread_2ch_get_url_to_post(OchushaBBSThread *thread);
 
 
@@ -145,8 +150,10 @@ ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
     = ochusha_thread_2ch_write_threadlist_element;
   b_class->get_responses_source = ochusha_thread_2ch_get_responses_source;
   b_class->parse_responses = ochusha_thread_2ch_parse_responses;
+  b_class->get_last_modified_utc = ochusha_thread_2ch_get_last_modified_utc;
   b_class->get_url
     = (const char *(*)(OchushaBBSThread *))ochusha_thread_2ch_get_base_url;
+  b_class->get_url_for_response = ochusha_thread_2ch_get_url_for_response;
   b_class->get_url_to_post = ochusha_thread_2ch_get_url_to_post;
   b_class->check_url = ochusha_thread_2ch_check_url;
   b_class->remove_cache = ochusha_thread_2ch_remove_cache;
@@ -933,6 +940,44 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
 }
 
 
+static time_t
+ochusha_thread_2ch_get_last_modified_utc(OchushaBBSThread *thread)
+{
+  OchushaThread2ch *thread_2ch;
+
+  g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), 0);
+
+  thread_2ch = OCHUSHA_THREAD_2CH(thread);
+  if (thread_2ch->last_modified == NULL)
+    return 0;
+
+  return ochusha_utils_get_utc_time(thread_2ch->last_modified);
+}
+
+
+static char *
+ochusha_thread_2ch_get_url_for_response(OchushaBBSThread *thread, int number)
+{
+  OchushaThread2ch *thread_2ch;
+  char url[PATH_MAX];
+  const char *base_url;
+
+  g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), NULL);
+
+  thread_2ch = OCHUSHA_THREAD_2CH(thread);
+
+  base_url = ochusha_thread_2ch_get_base_url(thread_2ch);
+  base_url = strstr(base_url, "/test/read.cgi");
+
+  if (base_url == NULL)
+    return NULL;
+
+  snprintf(url, PATH_MAX, "..%s%d", base_url, number);
+
+  return G_STRDUP(url);
+}
+
+
 static const char *
 ochusha_thread_2ch_get_url_to_post(OchushaBBSThread *thread)
 {
