@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.9 2003/11/04 08:58:38 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.10 2003/11/07 14:23:00 fuyu Exp $
  */
 
 #include "config.h"
@@ -546,6 +546,9 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
   ghttp_prepare(request);
   if (ghttp_process(request) == ghttp_error)
     {
+#if DEBUG_POST
+      fprintf(stderr, "ghttp_process() returns ghttp_error\n");
+#endif
       ghttp_request_destroy(request);
       ochusha_board_2ch_set_cookie(board_2ch, NULL);
     }
@@ -557,17 +560,17 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
       const char *body = ghttp_get_body(request);
       int len = ghttp_get_body_len(request);
       const char *x_2ch = g_strstr_len(body, len, "2ch_X:");
+#if DEBUG_POST_MOST
+      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
+				    NULL, NULL, NULL);
+      fprintf(stderr, "Set-Cookie: %s\n",
+	      ghttp_get_header(request, http_hdr_Set_Cookie));
+      fprintf(stderr, "Result-Body: %s\n", native_body);
+      g_free(native_body);
+#endif
 
       if (x_2ch != NULL)
 	{
-#if DEBUG_POST_MOST
-	  char *native_body = g_convert(body, len, "EUC-JP", "CP932",
-					NULL, NULL, NULL);
-	  fprintf(stderr, "Set-Cookie: %s\n",
-		  ghttp_get_header(request, http_hdr_Set_Cookie));
-	  fprintf(stderr, "Result-Body: %s\n", native_body);
-	  g_free(native_body);
-#endif
 	  if (g_strstr_len(x_2ch, len, "2ch_X:cookie") != NULL)
 	    {
 	      new_cookie = ghttp_get_header(request, http_hdr_Set_Cookie);
@@ -597,6 +600,20 @@ ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
 	    }
 	}
     }
+#if DEBUG_POST
+  else
+    {
+      const char *body = ghttp_get_body(request);
+      int len = ghttp_get_body_len(request);
+      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
+				    NULL, NULL, NULL);
+      fprintf(stderr, "status_code = %d\n", status_code);
+      fprintf(stderr, "Set-Cookie: %s\n",
+	      ghttp_get_header(request, http_hdr_Set_Cookie));
+      fprintf(stderr, "Result-Body: %s\n", native_body);
+      g_free(native_body);
+    }
+#endif
 
   ghttp_request_destroy(request);
 
